'''
    This is a simple module storing a global instance of ContextClass. It is
    used to hold the (few) globals that may be needed across manifest-edit.
'''

import libfmp4

class ContextClass:
    '''
    In particular, ContextClass is used to :

    - provide logging functions that can either point to external ones or be
      simple python prints (to be improved with python logging)
    - store an mp4context. This is optional and only needed in case you need
      to use libfmp4 logging functions
    - store the active pipeline for each format, as set up by the "setup" method
    - store the extension set up by the "setup" method (to be removed soon in
      favour of extension taken from manifest type)

    '''

    def __init__(self):
        self._pipeline = None
        self._mp4context = None
        # Default logging methods to be used only if an mp4 context is not
        #  available
        self.use_python_logs = False
        self.log_debug   = self.python_log_debug
        self.log_warning = self.python_log_warning
        self.log_error   = self.python_log_error
        self.log_trace   = self.python_log_trace

    def python_log_debug(self, msg):
        if self.use_python_logs:
            print('DEBUG: {}'.format(msg))

    def python_log_warning(self, msg):
        if self.use_python_logs:
            print('WARNING: {}'.format(msg))

    def python_log_error(self, msg):
        if self.use_python_logs:
            print('ERROR: {}'.format(msg))

    def python_log_trace(self, msg):
        if self.use_python_logs:
            print('TRACE: {}'.format(msg))

    def fmp4_log_debug(self, msg):
        return libfmp4.log_debug(self._mp4context, msg)

    def fmp4_log_warning(self, msg):
        return libfmp4.log_warning(self._mp4context, msg)

    def fmp4_log_error(self, msg):
        return libfmp4.log_error(self._mp4context, msg)

    def fmp4_log_trace(self, msg):
        return libfmp4.log_trace(self._mp4context, msg)

    @property
    def pipeline(self):
        return self._pipeline

    @pipeline.setter
    def pipeline(self, pipeline):
        self._pipeline = pipeline

    @property
    def mp4context(self):
        return self._mp4context

    @mp4context.setter
    def mp4context(self, mp4context):
        if mp4context is not None:
            self._mp4context = mp4context
            #Replacing default logging function with those from fmp4
            self.log_debug = self.fmp4_log_debug
            self.log_warning = self.fmp4_log_warning
            self.log_error = self.fmp4_log_error
            self.log_trace = self.fmp4_log_trace

Context = ContextClass()