from manifest_edit.plugin import BasePlugin, M3u8Main
from schema import Schema, Or
from manifest_edit.context import Context


class Plugin(M3u8Main, BasePlugin):
    '''A plugin that can change the default language in hls manifests

    DEFAULT: (Optional) A string indicating the media selection should be
             played if the user hasn't selected another option. Valid values
             are YES and NO.
    '''

    _name = __name__

    _keys = ['default']

    def schema(self):
        return Schema(
            {
                self._keys[0]: str,
            }
        )

    def process(self, manifest, storage):
        if not len(manifest.medias):
            Context.log_warning("The provided m3u8 manifest does not have"
                                " an EXT-X-MEDIA section! Skipping...")
            return

        # FIX DEFAULT
        language = self.config(storage=storage)[self._keys[0]]

        for media in manifest.medias:
            if media.type == "AUDIO":
                if media.language == language:
                    media.default = "YES"
                    media.autoselect = "YES"
                else:
                    media.default = "NO"
                    #will leave AUTOSELECT untouched
